@@ -5,8 +5,8 @@ from tippisell_api import methods, models, exceptions
 
 
 class BaseClient:
-    def __init__(self, shop_id: int, api_key: str):
-        self.shop_id = shop_id
+    def __init__(self, shop_id: typing.Union[str, int], api_key: str):
+        self.shop_id = str(shop_id)
         self.api_key = api_key
 
         self._base_url = "https://tippisell.xyz/api"
@@ -25,10 +25,8 @@ class BaseClient:
             kwargs = {
                 "params": method.get_params(),
             }
-        elif "post" == method.http_method:
-            kwargs = {
-                "json": method.get_json()
-            }
+        elif method.http_method in ["post", "delete"]:
+            kwargs = {"json": method.get_json()}
         else:
             raise NameError
 
@@ -43,5 +41,4 @@ class BaseClient:
             raise exceptions.InvalidApiKey
 
         if http_response.result["ok"] is False:
-            print(http_response.result["result"])
             raise exceptions.BaseTippisellException(http_response.result["message"])
