@@ -13,13 +13,16 @@ class WebhookRequestHandler(web.View):
         response_data = {}
         if "pre_sell" == data["type"]:
             response_data["result"] = await self.validate_sale(
-                models.User(**data["user"]), models.Product(**data["product"]), data["data"]
+                models.User(**data["user"]),
+                models.Product(**data["product"]),
+                data["data"],
             )
 
         return web.json_response(response_data)
 
     async def validate_sale(
-            self, user: models.User, product: models.Product, data: typing.List[str]) -> typing.List[dict]:
+        self, user: models.User, product: models.Product, data: typing.List[str]
+    ) -> typing.List[dict]:
         raise NotImplementedError
 
     def check_ip(self) -> bool:
